@@ -1,17 +1,15 @@
 # pylint: disable=missing-function-docstring
 """Keras (de)serialization test suite"""
 
-from tensorflow import keras
 import numpy as np
+from common import to_from_json
 from numpy.testing import assert_array_equal
+from tensorflow import keras  # pylint: disable=no-name-in-module
 
-from common import from_json, to_json  # Must be before turbo_broccoli imports
-
-from turbo_broccoli.environment import set_keras_format
+from turbo_broccoli import Context
 
 
 def _assert_model_equal(a, b):
-    assert a.get_config() == b.get_config()
     for i, w in enumerate(a.weights):
         assert_array_equal(w, b.weights[i])
     # Not really necessary but why not
@@ -40,18 +38,26 @@ def _build_model():
 
 
 def test_keras_model_json():
-    set_keras_format("json")
-    x = _build_model()
-    _assert_model_equal(x, from_json(to_json(x)))
+    ctx = Context(keras_format="json")
+    m1 = _build_model()
+    m2 = to_from_json(m1, ctx)
+    _assert_model_equal(m1, m2)
+    assert m1.get_config() == m2.get_config()
 
 
 def test_keras_model_h5():
-    set_keras_format("h5")
-    x = _build_model()
-    _assert_model_equal(x, from_json(to_json(x)))
+    ctx = Context(keras_format="h5")
+    m = _build_model()
+    _assert_model_equal(m, to_from_json(m, ctx))
+
+
+def test_keras_model_keras():
+    ctx = Context(keras_format="keras")
+    m = _build_model()
+    _assert_model_equal(m, to_from_json(m, ctx))
 
 
 def test_keras_model_tf():
-    set_keras_format("tf")
-    x = _build_model()
-    _assert_model_equal(x, from_json(to_json(x)))
+    ctx = Context(keras_format="tf")
+    m = _build_model()
+    _assert_model_equal(m, to_from_json(m, ctx))
